===================
Authors and Credits
===================

Thank you to everyone who has contributed to PyDL.
If we have neglected to include you, please let us know right away!

* `Kyle Barbary <https://github.com/kbarbary>`_
* `Larry Bradley <https://github.com/larrybradley>`_
* `Matt Craig <https://github.com/mwcraig>`_
* `Christoph Deil <https://github.com/cdeil>`_
* `Mike DiPompeo <https://github.com/mdipompe>`_
* `Joe Hennawi <https://github.com/jhennawi>`_
* `igoldste <https://github.com/igoldste>`_
* `Duncan Macleod <https://github.com/duncanmmacleod>`_
* `Demitri Muna <https://github.com/demitri>`_
* `Thomas Robitaille <https://github.com/astrofrog>`_
* `José Sánchez-Gallego <https://github.com/albireox>`_
* `Brigitta Sipocz <https://github.com/bsipocz>`_
* `Erik Tollerud <https://github.com/eteq>`_
* `ViviCoder <https://github.com/ViviCoder>`_
* `Benjamin Alan Weaver <https://github.com/weaverba137>`_
* `Kyle Westfall <https://github.com/kbwestfall>`_
